@@ -40,7 +40,7 @@ Example usage::
         writer(out, schema, records)
 '''
 
-__version_info__ = (0, 24, 2)
+__version_info__ = (1, 0, 0)
 __version__ = '%s.%s.%s' % __version_info__
 
 
@@ -49,7 +49,7 @@ import fastavro.write
 import fastavro.schema
 import fastavro.validation
 
-reader = iter_avro = fastavro.read.reader
+reader = fastavro.read.reader
 json_reader = fastavro.json_read.json_reader
 block_reader = fastavro.read.block_reader
 schemaless_reader = fastavro.read.schemaless_reader
