@@ -6,11 +6,11 @@
 # http://svn.apache.org/viewvc/avro/trunk/lang/py/src/avro/ which is under
 # Apache 2.0 license (http://www.apache.org/licenses/LICENSE-2.0)
 
-from fastavro.six import MemoryIO
+from io import BytesIO
 from struct import error as StructError
 import bz2
 import zlib
-import datetime
+from datetime import datetime, time, date, timezone, timedelta
 from decimal import Context
 from uuid import UUID
 
@@ -18,14 +18,10 @@ import json
 
 from .io.binary_decoder import BinaryDecoder
 from .io.json_decoder import AvroJSONDecoder
-from .six import (
-    xrange, btou, utob, iteritems, is_str, long, be_signed_bytes_to_int
-)
 from .schema import extract_record_type, extract_logical_type, parse_schema
 from ._read_common import (
     SchemaResolutionError, MAGIC, SYNC_SIZE, HEADER_SCHEMA, missing_codec_lib
 )
-from ._timezone import epoch
 from .const import (
     MCS_PER_HOUR, MCS_PER_MINUTE, MCS_PER_SECOND, MLS_PER_HOUR, MLS_PER_MINUTE,
     MLS_PER_SECOND, DAYS_SHIFT
@@ -53,6 +49,7 @@ AVRO_TYPES = {
 }
 
 decimal_context = Context()
+epoch = datetime(1970, 1, 1, tzinfo=timezone.utc)
 
 
 def match_types(writer_type, reader_type):
@@ -137,15 +134,17 @@ def read_boolean(
 
 
 def read_timestamp_millis(data, writer_schema=None, reader_schema=None):
-    return epoch + datetime.timedelta(microseconds=data * MLS_PER_SECOND)
+    # Cannot use datetime.fromtimestamp: https://bugs.python.org/issue36439
+    return epoch + timedelta(microseconds=data * 1000)
 
 
 def read_timestamp_micros(data, writer_schema=None, reader_schema=None):
-    return epoch + datetime.timedelta(microseconds=data)
+    # Cannot use datetime.fromtimestamp: https://bugs.python.org/issue36439
+    return epoch + timedelta(microseconds=data)
 
 
 def read_date(data, writer_schema=None, reader_schema=None):
-    return datetime.date.fromordinal(data + DAYS_SHIFT)
+    return date.fromordinal(data + DAYS_SHIFT)
 
 
 def read_uuid(data, writer_schema=None, reader_schema=None):
@@ -157,7 +156,7 @@ def read_time_millis(data, writer_schema=None, reader_schema=None):
     m = int(data / MLS_PER_MINUTE) % 60
     s = int(data / MLS_PER_SECOND) % 60
     mls = int(data % MLS_PER_SECOND) * 1000
-    return datetime.time(h, m, s, mls)
+    return time(h, m, s, mls)
 
 
 def read_time_micros(data, writer_schema=None, reader_schema=None):
@@ -165,14 +164,14 @@ def read_time_micros(data, writer_schema=None, reader_schema=None):
     m = int(data / MCS_PER_MINUTE) % 60
     s = int(data / MCS_PER_SECOND) % 60
     mcs = data % MCS_PER_SECOND
-    return datetime.time(h, m, s, mcs)
+    return time(h, m, s, mcs)
 
 
 def read_decimal(data, writer_schema=None, reader_schema=None):
     scale = writer_schema.get('scale', 0)
     precision = writer_schema['precision']
 
-    unscaled_datum = be_signed_bytes_to_int(data)
+    unscaled_datum = int.from_bytes(data, byteorder='big', signed=True)
 
     decimal_context.prec = precision
     return decimal_context.create_decimal(unscaled_datum). \
@@ -480,7 +479,7 @@ def read_record(
         # fill in default values
         if len(readers_field_dict) > len(record):
             writer_fields = [f['name'] for f in writer_schema['fields']]
-            for f_name, field in iteritems(readers_field_dict):
+            for f_name, field in readers_field_dict.items():
                 if f_name not in writer_fields and f_name not in record:
                     if 'default' in field:
                         record[field['name']] = field['default']
@@ -525,17 +524,16 @@ READERS = {
 
 def maybe_promote(data, writer_type, reader_type):
     if writer_type == "int":
-        if reader_type == "long":
-            return long(data)
+        # No need to promote to long since they are the same type in Python
         if reader_type == "float" or reader_type == "double":
             return float(data)
     if writer_type == "long":
         if reader_type == "float" or reader_type == "double":
             return float(data)
     if writer_type == "string" and reader_type == "bytes":
-        return utob(data)
+        return data.encode()
     if writer_type == "bytes" and reader_type == "string":
-        return btou(data, 'utf-8')
+        return data.decode()
     return data
 
 
@@ -600,7 +598,7 @@ def skip_sync(fo, sync_marker):
 
 def null_read_block(decoder):
     """Read block in "null" codec."""
-    return MemoryIO(decoder.read_bytes())
+    return BytesIO(decoder.read_bytes())
 
 
 def deflate_read_block(decoder):
@@ -608,13 +606,13 @@ def deflate_read_block(decoder):
     data = decoder.read_bytes()
     # -15 is the log of the window size; negative indicates "raw" (no
     # zlib headers) decompression.  See zlib.h.
-    return MemoryIO(zlib.decompress(data, -15))
+    return BytesIO(zlib.decompress(data, -15))
 
 
 def bzip2_read_block(decoder):
     """Read block in "bzip2" codec."""
     data = decoder.read_bytes()
-    return MemoryIO(bz2.decompress(data))
+    return BytesIO(bz2.decompress(data))
 
 
 BLOCK_READERS = {
@@ -628,7 +626,7 @@ def snappy_read_block(decoder):
     length = read_long(decoder)
     data = decoder.read_fixed(length - 4)
     decoder.read_fixed(4)  # CRC
-    return MemoryIO(snappy.decompress(data))
+    return BytesIO(snappy.decompress(data))
 
 
 try:
@@ -642,7 +640,7 @@ else:
 def zstandard_read_block(decoder):
     length = read_long(decoder)
     data = decoder.read_fixed(length)
-    return MemoryIO(zstd.ZstdDecompressor().decompress(data))
+    return BytesIO(zstd.ZstdDecompressor().decompress(data))
 
 
 try:
@@ -656,7 +654,7 @@ else:
 def lz4_read_block(decoder):
     length = read_long(decoder)
     data = decoder.read_fixed(length)
-    return MemoryIO(lz4.block.decompress(data))
+    return BytesIO(lz4.block.decompress(data))
 
 
 try:
@@ -670,7 +668,7 @@ else:
 def xz_read_block(decoder):
     length = read_long(decoder)
     data = decoder.read_fixed(length)
-    return MemoryIO(lzma.decompress(data))
+    return BytesIO(lzma.decompress(data))
 
 
 try:
@@ -711,7 +709,7 @@ def _iter_avro_records(
 
         block_fo = read_block(decoder)
 
-        for i in xrange(block_count):
+        for i in range(block_count):
             yield read_data(
                 BinaryDecoder(block_fo),
                 writer_schema,
@@ -812,7 +810,7 @@ class Block:
         self.return_record_name = return_record_name
 
     def __iter__(self):
-        for i in xrange(self.num_records):
+        for i in range(self.num_records):
             yield read_data(
                 BinaryDecoder(self.bytes_),
                 self.writer_schema,
@@ -862,7 +860,7 @@ class file_reader(object):
 
         # `meta` values are bytes. So, the actual decoding has to be external.
         self.metadata = {
-            k: btou(v) for k, v in iteritems(self._header['meta'])
+            k: v.decode() for k, v in self._header['meta'].items()
         }
 
         self._schema = json.loads(self.metadata['avro.schema'])
@@ -1094,7 +1092,7 @@ def is_avro(path_or_buffer):
     path_or_buffer: path to file or file-like object
         Path to file
     """
-    if is_str(path_or_buffer):
+    if isinstance(path_or_buffer, str):
         fp = open(path_or_buffer, 'rb')
         close = True
     else:
